@@ -17,6 +17,7 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include <string.h>
 #include <sys/socket.h>
 #include <linux/netdevice.h>
 #include <team.h>
@@ -40,6 +41,15 @@ static int lb_event_watch_port_added(struct teamd_context *ctx,
 			      tdport->ifname);
 		return err;
 	}
+
+	if (!team_is_port_link_up(tdport->team_port)) {
+		err = team_set_port_enabled(ctx->th, tdport->ifindex, false);
+		if (err) {
+			teamd_log_err("%s: Failed to disable port.",
+				      tdport->ifname);
+			return TEAMD_ENOENT(err) ? 0 : err;
+		}
+	}
 	return teamd_balancer_port_added(lb->tb, tdport);
 }
 
@@ -78,11 +88,49 @@ static int lb_event_watch_hwaddr_changed(struct teamd_context *ctx, void *priv)
 	return 0;
 }
 
+static int lb_event_watch_port_hwaddr_changed(struct teamd_context *ctx,
+					      struct teamd_port *tdport,
+					      void *priv)
+{
+	int err;
+
+	if (!teamd_port_present(ctx, tdport))
+		return 0;
+
+	if (!memcmp(team_get_ifinfo_hwaddr(tdport->team_ifinfo),
+		    ctx->hwaddr, ctx->hwaddr_len))
+		return 0;
+
+	err = team_hwaddr_set(ctx->th, tdport->ifindex, ctx->hwaddr,
+			      ctx->hwaddr_len);
+	if (err)
+		teamd_log_err("%s: Failed to set port hardware address.",
+			      tdport->ifname);
+
+	return err;
+}
+
+static int lb_event_watch_enabled_option_changed(struct teamd_context *ctx,
+						 struct team_option *option,
+						 void *priv)
+{
+	struct teamd_port *tdport;
+
+	tdport = teamd_get_port(ctx, team_get_option_port_ifindex(option));
+	if (!tdport)
+		return 0;
+
+	return lb_event_watch_port_link_changed(ctx, tdport, priv);
+}
+
 static const struct teamd_event_watch_ops lb_port_watch_ops = {
 	.hwaddr_changed = lb_event_watch_hwaddr_changed,
+	.port_hwaddr_changed = lb_event_watch_port_hwaddr_changed,
 	.port_added = lb_event_watch_port_added,
 	.port_removed = lb_event_watch_port_removed,
 	.port_link_changed = lb_event_watch_port_link_changed,
+	.option_changed = lb_event_watch_enabled_option_changed,
+	.option_changed_match_name = "enabled",
 };
 
 static int lb_init(struct teamd_context *ctx, void *priv)
